capture log close
log using asian, replace text
set more off
set scheme sj


use asian, clear

* plot observed growth trajectories
label def g 1 "Boy" 2 "Girl"
label values gender g

sort id age
graph twoway (line weight age, connect(ascending)), ///
  by(gender) xtitle(Age in years) ytitle(Weight in Kg)


/* estimation using xtmixed */
gen age2 = age^2
xtmixed weight age age2 || id:, mle
xtmixed weight age age2 || id: age, cov(unstr) mle

gen girl = gender-1
xtmixed weight age age2 girl || id: age, cov(unstr) mle

gen age_girl = age*girl
xtmixed weight age age2 girl age_girl|| id: age, cov(unstr) mle

 
/* estimation using  gllamm */
* random intercept model
gen cons=1
eq inter: cons
gllamm weight age age2, i(id) eqs(inter) adapt

* random coefficient model
matrix a=e(b)
eq slope: age
gllamm weight age age2, i(id) nrf(2) eqs(inter slope) ip(m) nip(15) from(a) adapt
matrix a=e(b)

* include girl
gllamm weight age age2 girl, i(id) nrf(2) eqs(inter slope) ip(m) nip(15) from(a) adapt
matrix a=e(b)

* two-stage model formulation
eq r1:  cons girl
eq r2:  cons girl
gllamm weight age2, nocons i(id) nrf(2) eqs(inter slope) ip(m) nip(15) ///
  geqs(r1 r2) adapt
  
gllamm weight age age2 girl age_girl , i(id) nrf(2) eqs(inter slope) ip(m) nip(15) from(a) adapt

* prediction of individual growth trajectories
xtmixed weight age age2 girl age_girl|| id: age, cov(unstr) mle
predict traj, fitted

graph twoway (line traj age, connect(ascending)) ///
 (line weight age, connect(ascending) clpatt(dash)), ///
 by(gender) xtitle(Age in years) ytitle(Weight in Kg) ///
 legend(order(1 "Predicted" 2 "Observed"))

graph twoway (line traj age, connect(ascending)), ///
 by(gender) xtitle(Age in years) ytitle(Weight in Kg) ///
 legend(off)

/* complex variation */
gen boy=1-girl
eq het: girl boy
gllamm weight age age2 girl, i(id) nrf(2) eqs(inter slope) s(het) adapt
disp exp(-.606*2)
disp exp(-.447*2)
display chiprob(1,2*(253.87-252.41))

log close
exit
