capture log close
log using toenail, replace text
set more off
set scheme sj

use toenail, clear

/* summary statistics and graphs */
xtdes, i(patient) t(visit)

label define tr 0 "Itraconazole" 1 "Terbinafine"
label values treat tr

graph bar (mean) proportion= outcome, over(visit) by(treatment) ///
   ytitle(Proportion with onycholysis)

egen prop = mean(outcome), by(treatment visit)
egen mn_month = mean(month), by(treatment visit)

twoway line prop mn_month, by(treatment) sort ///
  xtitle(Time in months) ytitle(Proportion of onycholysis)

/* models */

* ordinary logistic regression
gen trt_month = treatment*month
logit outcome treatment month trt_month, or
predict prob, p

twoway (line prop mn_month, sort) (line prob month, sort clpatt(dash) ), ///
   by(treatment) ///
   legend(order(1 "Observed proportions" 2 "Fitted probabilities")) ///
   xtitle(Time in months) ytitle(Probability of onycholysis)

* random intercept model
gllamm outcome treatment month trt_month, i(patient) ///
  family(binom) link(logit) nip(30) adapt
gllamm, eform

* population averaged probabilities
gllapred margprob, mu marg

twoway (line prob month, sort) (line margprob month, sort clpatt(dash) ), ///
   by(treatment) legend(order(1 "Ordinary logit" 2 "Random intercept logit")) ///
   xtitle(Time in months) ytitle(Fitted marginal probabilities of onycholysis)

* conditional, subject-specific probabilities
gen zeta1=0
gllapred condprob0, mu us(zeta)
gen lower1 = -4
gllapred condprobm4, mu us(lower)
gen upper1 = 4
gllapred condprob4, mu us(upper)
replace lower1 = -2
gllapred condprobm2, mu us(lower)
replace upper1 = 2
gllapred condprob2, mu us(upper)

twoway (line prop mn_month, sort) ///
 (line margprob month, sort clpatt(dash)) ///
 (line condprob0 month, sort clpatt(dot) clwidth(medthick)) ///
 (line condprob4 month, sort clpatt(dot) clwidth(medthick)) ///
 (line condprobm4 month, sort clpatt(dot) clwidth(medthick)) ///
 (line condprob2 month, sort clpatt(dot) clwidth(medthick)) ///
 (line condprobm2 month, sort clpatt(dot)clwidth(medthick)), ///
 by(treatment) ///
 legend(order(1 "Observed proportions" 2 "Marginal probabities" 3 "Conditional probabilities")) ///
 xtitle(Time in months) ytitle(Probabilities of onycholysis)

* empirical Bayes predictions
gllapred zeta, u
gllapred mu, mu

drop if treatment==0
keep patient outcome visit zetam1 zetas1 mu
reshape wide outcome mu, i(patient) j(visit)

egen quintiles = cut(zetam1), group(5)
bysort quintiles (zetam1): gen select=_n==round(_N/2,1)
keep if select

format zeta* mu* %3.2f
sort zetam1
list zetam1 zetas1 outcome*, clean noobs abbreviate(3)
list zetam1 mu*, clean noobs
 
* Other approaches to clustered dichotomous data
clogit outcome month trt_month, group(patient) eform
xtgee outcome treatment month trt_month, i(patient) link(logit) ///
  family(binom) robust eform
  
log close
exit
